@@ -1,7 +1,7 @@
 from django.conf.urls.defaults import *
-import sentry_tracpost.plugin as plugin
+from sentry_tracpost.plugin import start
 uuid_re = r'\b[A-F0-9]{8}(?:-[A-F0-9]{4}){3}-[A-Z0-9]{12}\b|$'
 
 urlpatterns = patterns('',
-    url(r'^tracpost/$', 'plugin.TracPost.send_message', name='send_message'),
+    url(r'^tracpost/$', 'start', name='send_message'),
 )
